@@ -1,3 +1,7 @@
+#define DEBUG 1
+#define OSSOLOG_SYSLOG 1
+#include <osso-log.h>
+
 #include <QApplication>
 #include <qmaemo5homescreenadaptor.h>
 #include "profilechangerwidget.h"
@@ -7,7 +11,8 @@ int main(int argc, char *argv[])
     QApplication::setOrganizationName("hschmitt");
     QApplication::setApplicationName("profile-changer-widget");
     QApplication::setApplicationVersion("0.4-5");
-    qWarning("Starting profile-changer-widget");
+    ULOG_INFO_L("Starting profile-changer-widget");
+    ULOG_WARN_L("Starting profile-changer-widget");
     // enforce native graphics system for now due to a bug in transparency handling
     // you can remove this line if you only target PR 1.2
     if (qstrcmp(qVersion(), "4.7.2") == 0) {
@@ -37,7 +42,7 @@ int main(int argc, char *argv[])
 
     qWarning("profile-changer-widget show");
     w.show();
-    qWarning("profile-changer-widget app.exec");
+    ULOG_INFO_L("profile-changer-widget app.exec");
     app.exec();
 }
 
